@@ -23,7 +23,3 @@ dofile(modpath .. "/nodes.lua")
 dofile(modpath .. "/redefinitions.lua")
 dofile(modpath .. "/crafting.lua")
 dofile(modpath .. "/aliases.lua")
-
-if minetest.settings:get_bool("log_mods") then
-	minetest.log("action", S("[moreblocks] loaded."))
-end
